package Khonsu::Form::Field::Input;

use parent 'Khonsu::Form::Field';

use PDF::API2::Basic::PDF::Literal;
use PDF::API2::Basic::PDF::Utils;

sub configure {
	my ($self) = @_;
	$self->annotate->{FT} = PDFName('Tx');

}


1;
